@@ -31,7 +31,7 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
         _vintage_: Text for the vintage of the template system. This will be used
             to set efficiencies for various pieces of equipment within the system.
             The "HB Building Vintages" component has a full list of supported
-            HVAC vintages. (Default: ASHRAE_2013).
+            HVAC vintages. (Default: ASHRAE_2019).
         _name_: Text to set the name for the heating/cooling system and to be
             incorporated into unique system identifier. If the name is not
             provided, a random name will be assigned.
@@ -42,7 +42,7 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
 
 ghenv.Component.Name = "DF HeatCool HVAC"
 ghenv.Component.NickName = 'DFHeatCoolHVAC'
-ghenv.Component.Message = '1.2.1'
+ghenv.Component.Message = '1.2.2'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '3 :: Energy'
 ghenv.Component.AdditionalHelpFromDocStrings = '3'
@@ -88,6 +88,8 @@ vintages = {
     'ASHRAE_2007': 'ASHRAE_2007',
     'ASHRAE_2010': 'ASHRAE_2010',
     'ASHRAE_2013': 'ASHRAE_2013',
+    'ASHRAE_2016': 'ASHRAE_2016',
+    'ASHRAE_2019': 'ASHRAE_2019',
     'DOE Ref Pre-1980': 'DOE_Ref_Pre_1980',
     'DOE Ref 1980-2004': 'DOE_Ref_1980_2004',
     '90.1-2004': 'ASHRAE_2004',
@@ -100,8 +102,10 @@ vintages = {
     '2007': 'ASHRAE_2007',
     '2010': 'ASHRAE_2010',
     '2013': 'ASHRAE_2013',
-    None: 'ASHRAE_2013'
-    }
+    '2016': 'ASHRAE_2016',
+    '2019': 'ASHRAE_2019',
+    None: 'ASHRAE_2019'
+}
 
 # dictionary of HVAC template names
 ext_folder = folders.standards_extension_folders[0]
